(x,0) where x positive.Computes first part of latent trawl pairwise likelihood with (x,0) where x positive.
PairwiseOneZero1(x1, alpha, beta, kappa, trawlA)Positive value corresponding to t1.
Shape parameter. Should be positive.
Latent Gamma scale parameter. Should be positive.
Exceedance probability parameter. Should be positive.
Total trawl set measure / area under trawl function.
first part of latent trawl pairwise likelihood with (x,0) where x positive.