(x,y) = (0,0).Computes second part of latent trawl pairwise likelihood with (x,y) = (0,0).
PairwiseZeroZero2(alpha, beta, kappa, B1, B2, B3)Shape parameter. Should be positive.
Latent Gamma scale parameter. Should be positive.
Exceedance probability parameter. Should be positive.
Difference area between times t1 and t2.
Intersection area between times t1 and t2.
Difference area between times t2 and t1.
Second part of latent trawl pairwise likelihood with (x,y) = (0,0).